use lib "/usr/local/libdata/perl5/site_perl/CIL";
$::archos    = "libexec/cil";
$::cc        = "/usr/bin/gcc";
$::cilhome   = "/usr/local";
$::default_mode = "GNUCC";

